@@ -1,16 +1,25 @@
 # pylint: disable = import-error, import-outside-toplevel, dangerous-default-value, invalid-name, R0801
 """Main TrustyAI Python bindings"""
 from typing import List
+import site
+import os
 import uuid
 import jpype
 import jpype.imports
 from jpype import _jcustomizer, _jclass
 
-TRUSTY_VERSION = "1.12.0.Final"
+TRUSTY_VERSION = "1.17.0.Final"
+DEFAULT_DEP_PATH = os.path.join(site.getsitepackages()[0], "trustyai", "dep")
+
 CORE_DEPS = [
-    f"./dep/org/kie/kogito/explainability-core/{TRUSTY_VERSION}/*",
-    "./dep/org/slf4j/slf4j-api/1.7.30/slf4j-api-1.7.30.jar",
-    "./dep/org/apache/commons/commons-lang3/3.12.0/commons-lang3-3.12.0.jar",
+    f"{DEFAULT_DEP_PATH}/org/kie/kogito/explainability-core/{TRUSTY_VERSION}/*",
+    f"{DEFAULT_DEP_PATH}/org/slf4j/slf4j-api/1.7.30/slf4j-api-1.7.30.jar",
+    f"{DEFAULT_DEP_PATH}/org/apache/commons/commons-lang3/3.12.0/commons-lang3-3.12.0.jar",
+    f"{DEFAULT_DEP_PATH}/org/optaplanner/optaplanner-core/8.17.0.Final/"
+    f"optaplanner-core-8.17.0.Final.jar",
+    f"{DEFAULT_DEP_PATH}/org/apache/commons/commons-math3/3.6.1/commons-math3-3.6.1.jar",
+    f"{DEFAULT_DEP_PATH}/org/kie/kie-api/8.17.0.Beta/kie-api-8.17.0.Beta.jar",
+    f"{DEFAULT_DEP_PATH}/io/micrometer/micrometer-core/1.8.2/micrometer-core-1.8.2.jar",
 ]
 
 
